/*
 * lesslog - PostgreSQL archive log size reduction utility
 *
 *    Copyright(C) 2008 Nippon Telegraph and Telephone Corporation
 *
 *    Contact: suzuki.koichi@oss.ntt.co.jp
 */

/*
 * remove_handler.h
 *    replace physical log with logical log while WAL archiving.
 */
#ifndef REMOVE_HANDLER_H_INCLUDED
#define REMOVE_HANDLER_H_INCLUDED

#include "postgres.h"
#include "access/xlog.h"

/* =============================================================================
 * Prototypes
 * ===========================================================================*/
/* Functions to remove backup blocks. */
uint32 remove_common(XLogRecord *record,
	const char *rec_pos, const char *next_pos);

uint32 remove_heap_insert(XLogRecord *record,
	const char *rec_pos, const char *next_pos);
uint32 remove_heap_update(XLogRecord *record,
	const char *rec_pos, const char *next_pos, bool move);
uint32 remove_heap_inplace(XLogRecord *record,
	const char *rec_pos, const char *next_pos);
uint32 remove_heap2_freeze(XLogRecord *record,
	const char *rec_pos, const char *next_pos);
uint32 remove_heap2_clean(XLogRecord *record,
	const char *rec_pos, const char *next_pos);

uint32 remove_btree_insert(XLogRecord *record,
	const char *rec_pos, const char *next_pos);
uint32 remove_btree_split(XLogRecord *record,
	const char *rec_pos, const char *next_pos, bool onleft);

uint32 remove_gist_new_root(XLogRecord *record,
	const char *rec_pos, const char *next_pos);

#endif /* REMOVE_HANDLER_H_INCLUDED */

